"""TRANSLATIONS stuff using Gettext"""
import gettext
import logging
import os.path

from django.conf import settings

log = logging.getLogger(__name__)

DOMAIN = "eeauthentic2"
TRANSLATIONS = None


def get_translations(domain, localedir=None, fallback=True):
    """Return configured GNUTranslation object for specified domain"""
    languages = (
        settings.EEA2_DEFAULT_LANGUAGES if hasattr(settings, "EEA2_DEFAULT_LANGUAGES") else None
    )
    log.info(
        "Initialized translations for domain %s with directory %s and %s",
        DOMAIN,
        localedir,
        f"languages {', '.join(languages)}" if languages else "auto-detected languages",
    )
    return gettext.translation(domain, localedir=localedir, languages=languages, fallback=fallback)


def initialize():
    """Initialize translations"""
    global TRANSLATIONS  # pylint: disable=global-statement
    if TRANSLATIONS:
        return

    TRANSLATIONS = get_translations(
        DOMAIN, localedir=os.path.join(os.path.abspath(os.path.dirname(__file__)), "locales")
    )


def _(*args, **kwargs):
    """Custom gettext _() method that handle auto-initialization and domain translations mapping"""
    initialize()
    domain = kwargs.pop("domain", DOMAIN)
    if domain == DOMAIN and TRANSLATIONS:
        return TRANSLATIONS.gettext(*args, **kwargs)
    return gettext.dgettext(domain, *args, **kwargs)


# vim: tabstop=4 shiftwidth=4 softtabstop=4 expandtab
